emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/emacs-24 r110856: Use new names for hooks r


From: Glenn Morris
Subject: [Emacs-diffs] /srv/bzr/emacs/emacs-24 r110856: Use new names for hooks rather than obsolete aliases
Date: Mon, 12 Nov 2012 19:11:46 -0800
User-agent: Bazaar (2.5.0)

------------------------------------------------------------
revno: 110856
committer: Glenn Morris <address@hidden>
branch nick: emacs-24
timestamp: Mon 2012-11-12 19:11:46 -0800
message:
  Use new names for hooks rather than obsolete aliases
  
  * lisp/cedet/semantic/lex-spp.el (semantic-lex-spp-lex-text-string):
  * lisp/cedet/semantic/util.el (semantic-describe-buffer):
  * lisp/cedet/semantic/bovine/c.el (semantic-c-parse-lexical-token)
  (semantic-default-c-setup):
  * lisp/emacs-lisp/eieio-datadebug.el (eieio-debug-methodinvoke):
  * lisp/gnus/gnus-diary.el (nndiary-request-create-group-functions)
  (nndiary-request-update-info-functions)
  (gnus-subscribe-newsgroup-functions)
  (nndiary-request-accept-article-functions):
  * lisp/net/tramp-gvfs.el (tramp-gvfs-dbus-event-error):
  Use new names for hooks rather than obsolete aliases.
  
  * lisp/arc-mode.el:
  * lisp/emacs-lisp/checkdoc.el: Related comments.
  
  * etc/NEWS: Related markup.
modified:
  etc/NEWS
  lisp/ChangeLog
  lisp/arc-mode.el
  lisp/cedet/ChangeLog
  lisp/cedet/semantic/bovine/c.el
  lisp/cedet/semantic/lex-spp.el
  lisp/cedet/semantic/util.el
  lisp/emacs-lisp/checkdoc.el
  lisp/emacs-lisp/eieio-datadebug.el
  lisp/gnus/ChangeLog
  lisp/gnus/gnus-diary.el
  lisp/net/tramp-gvfs.el
=== modified file 'etc/NEWS'
--- a/etc/NEWS  2012-11-12 19:44:39 +0000
+++ b/etc/NEWS  2012-11-13 03:11:46 +0000
@@ -629,6 +629,7 @@
 
 ** FIXME something happened to ses.el, 2012-04-17.
 
++++
 ** Hooks renamed to avoid obsolete "-hooks" suffix:
 *** semantic-lex-reset-hooks -> semantic-lex-reset-functions
 *** semantic-change-hooks -> semantic-change-functions

=== modified file 'lisp/ChangeLog'
--- a/lisp/ChangeLog    2012-11-12 21:31:15 +0000
+++ b/lisp/ChangeLog    2012-11-13 03:11:46 +0000
@@ -1,3 +1,9 @@
+2012-11-13  Glenn Morris  <address@hidden>
+
+       * emacs-lisp/eieio-datadebug.el (eieio-debug-methodinvoke):
+       * net/tramp-gvfs.el (tramp-gvfs-dbus-event-error):
+       Use new names for hooks rather than obsolete aliases.
+
 2012-11-12  Stefan Monnier  <address@hidden>
 
        * emacs-lisp/gv.el (gv-define-simple-setter): One more fix (bug#12871).

=== modified file 'lisp/arc-mode.el'
--- a/lisp/arc-mode.el  2012-10-23 15:06:07 +0000
+++ b/lisp/arc-mode.el  2012-11-13 03:11:46 +0000
@@ -96,7 +96,7 @@
 ;;
 ;; archive-mode-hook
 ;; archive-foo-mode-hook
-;; archive-extract-hooks
+;; archive-extract-hook
 
 ;;; Code:
 

=== modified file 'lisp/cedet/ChangeLog'
--- a/lisp/cedet/ChangeLog      2012-11-12 16:50:08 +0000
+++ b/lisp/cedet/ChangeLog      2012-11-13 03:11:46 +0000
@@ -1,3 +1,11 @@
+2012-11-13  Glenn Morris  <address@hidden>
+
+       * semantic/lex-spp.el (semantic-lex-spp-lex-text-string):
+       * semantic/util.el (semantic-describe-buffer):
+       * semantic/bovine/c.el (semantic-c-parse-lexical-token)
+       (semantic-default-c-setup):
+       Use new names for hooks rather than obsolete aliases.
+
 2012-11-12  Stefan Monnier  <address@hidden>
 
        * semantic/mru-bookmark.el (semantic-mru-bookmark-mode):

=== modified file 'lisp/cedet/semantic/bovine/c.el'
--- a/lisp/cedet/semantic/bovine/c.el   2012-10-05 05:57:24 +0000
+++ b/lisp/cedet/semantic/bovine/c.el   2012-11-13 03:11:46 +0000
@@ -931,8 +931,8 @@
          (setq semantic-new-buffer-fcn-was-run t)
          (semantic-lex-init)
          (semantic-clear-toplevel-cache)
-         (remove-hook 'semantic-lex-reset-hooks 'semantic-lex-spp-reset-hook
-                      t)
+         (remove-hook 'semantic-lex-reset-functions
+                      'semantic-lex-spp-reset-hook t)
          )
        ;; Get the macro symbol table right.
        (setq semantic-lex-spp-dynamic-macro-symbol-obarray spp-syms)
@@ -2073,7 +2073,7 @@
         )
 
   (setq semantic-lex-analyzer #'semantic-c-lexer)
-  (add-hook 'semantic-lex-reset-hooks 'semantic-lex-spp-reset-hook nil t)
+  (add-hook 'semantic-lex-reset-functions 'semantic-lex-spp-reset-hook nil t)
   (when (eq major-mode 'c++-mode)
     (add-to-list 'semantic-lex-c-preprocessor-symbol-map '("__cplusplus" . 
"")))
   )

=== modified file 'lisp/cedet/semantic/lex-spp.el'
--- a/lisp/cedet/semantic/lex-spp.el    2012-10-05 05:57:24 +0000
+++ b/lisp/cedet/semantic/lex-spp.el    2012-11-13 03:11:46 +0000
@@ -30,7 +30,7 @@
 ;; If you use SPP in your language, be sure to specify this in your
 ;; semantic language setup function:
 ;;
-;; (add-hook 'semantic-lex-reset-hooks 'semantic-lex-spp-reset-hook nil t)
+;; (add-hook 'semantic-lex-reset-functions 'semantic-lex-spp-reset-hook nil t)
 ;;
 ;;
 ;; Special Lexical Tokens:
@@ -947,8 +947,8 @@
            (setq semantic-new-buffer-fcn-was-run t)
            (semantic-lex-init)
            (semantic-clear-toplevel-cache)
-           (remove-hook 'semantic-lex-reset-hooks 'semantic-lex-spp-reset-hook
-                        t)
+           (remove-hook 'semantic-lex-reset-functions
+                        'semantic-lex-spp-reset-hook t)
            ))
 
        ;; Second Cheat: copy key variables regarding macro state from the

=== modified file 'lisp/cedet/semantic/util.el'
--- a/lisp/cedet/semantic/util.el       2012-10-01 18:10:29 +0000
+++ b/lisp/cedet/semantic/util.el       2012-11-13 03:11:46 +0000
@@ -280,7 +280,7 @@
                      semantic-parser-name
                      semantic-parse-tree-state
                      semantic-lex-analyzer
-                     semantic-lex-reset-hooks
+                     semantic-lex-reset-functions
                      semantic-lex-syntax-modifications
                      )))
          (dolist (V vars)

=== modified file 'lisp/emacs-lisp/checkdoc.el'
--- a/lisp/emacs-lisp/checkdoc.el       2012-10-23 17:09:22 +0000
+++ b/lisp/emacs-lisp/checkdoc.el       2012-11-13 03:11:46 +0000
@@ -124,7 +124,7 @@
 ;; Adding your own checks:
 ;;
 ;;   You can experiment with adding your own checks by setting the
-;; hooks `checkdoc-style-functions' and `checkdoc-comment-style-hooks'.
+;; hooks `checkdoc-style-functions' and `checkdoc-comment-style-functions'.
 ;; Return a string which is the error you wish to report.  The cursor
 ;; position should be preserved.
 ;;

=== modified file 'lisp/emacs-lisp/eieio-datadebug.el'
--- a/lisp/emacs-lisp/eieio-datadebug.el        2012-10-01 18:10:29 +0000
+++ b/lisp/emacs-lisp/eieio-datadebug.el        2012-11-13 03:11:46 +0000
@@ -131,7 +131,7 @@
 (defun eieio-debug-methodinvoke (method class)
   "Show the method invocation order for METHOD with CLASS object."
   (interactive "aMethod: \nXClass Expression: ")
-  (let* ((eieio-pre-method-execution-hooks
+  (let* ((eieio-pre-method-execution-functions
          (lambda (l) (throw 'moose l) ))
         (data
          (catch 'moose (eieio-generic-call

=== modified file 'lisp/gnus/ChangeLog'
--- a/lisp/gnus/ChangeLog       2012-10-23 15:06:07 +0000
+++ b/lisp/gnus/ChangeLog       2012-11-13 03:11:46 +0000
@@ -1,3 +1,11 @@
+2012-11-13  Glenn Morris  <address@hidden>
+
+       * gnus-diary.el (nndiary-request-create-group-functions)
+       (nndiary-request-update-info-functions)
+       (gnus-subscribe-newsgroup-functions)
+       (nndiary-request-accept-article-functions):
+       Use new names for hooks rather than obsolete aliases.
+
 2012-10-23  Stefan Monnier  <address@hidden>
 
        * nndiary.el (nndiary-request-create-group-functions)

=== modified file 'lisp/gnus/gnus-diary.el'
--- a/lisp/net/tramp-gvfs.el    2012-10-09 12:49:02 +0000
+++ b/lisp/net/tramp-gvfs.el    2012-11-13 03:11:46 +0000
@@ -521,12 +521,12 @@
 is no information where to trace the message.")
 
 (defun tramp-gvfs-dbus-event-error (event err)
-  "Called when a D-Bus error message arrives, see `dbus-event-error-hooks'."
+  "Called when a D-Bus error message arrives, see 
`dbus-event-error-functions'."
   (when tramp-gvfs-dbus-event-vector
     (tramp-message tramp-gvfs-dbus-event-vector 10 "%S" event)
     (tramp-error tramp-gvfs-dbus-event-vector 'file-error "%s" (cadr err))))
 
-(add-hook 'dbus-event-error-hooks 'tramp-gvfs-dbus-event-error)
+(add-hook 'dbus-event-error-functions 'tramp-gvfs-dbus-event-error)
 
 
 ;; File name primitives.


reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- a/lisp/gnus/gnus-diary.el   2012-01-19 07:21:25 +0000
+++ b/lisp/gnus/gnus-diary.el   2012-11-13 03:11:46 +0000
@@ -277,18 +277,18 @@
 
 ;; Called when a group is subscribed. This is needed because groups created
 ;; because of mail splitting are *not* created with the back end function.
 ;; Thus, `nndiary-request-create-group-hooks' is inoperative.
 (defun gnus-diary-maybe-update-group-parameters (group)
   (when (eq (car (gnus-find-method-for-group group)) 'nndiary)
     (gnus-diary-update-group-parameters group)))
 
-(add-hook 'nndiary-request-create-group-hooks
+(add-hook 'nndiary-request-create-group-functions
          'gnus-diary-update-group-parameters)
 ;; Now that we have `gnus-subscribe-newsgroup-hooks', this is not needed
 ;; anymore. Maybe I should remove this completely.
-(add-hook 'nndiary-request-update-info-hooks
+(add-hook 'nndiary-request-update-info-functions
          'gnus-diary-update-group-parameters)
-(add-hook 'gnus-subscribe-newsgroup-hooks
+(add-hook 'gnus-subscribe-newsgroup-functions
          'gnus-diary-maybe-update-group-parameters)
 
 
@@ -384,7 +384,7 @@
      nndiary-headers)
     ))
 
-(add-hook 'nndiary-request-accept-article-hooks
+(add-hook 'nndiary-request-accept-article-functions
          (lambda () (gnus-diary-check-message nil)))
 
 (define-key message-mode-map "\C-c\C-fd" 'gnus-diary-check-message)
@@ -277,18 +277,18 @@
 ;; Called when a group is subscribed. This is needed because groups created
 ;; because of mail splitting are *not* created with the back end function.
-;; Thus, `nndiary-request-create-group-hooks' is inoperative.
+;; Thus, `nndiary-request-create-group-functions' is inoperative.
 (defun gnus-diary-maybe-update-group-parameters (group)
   (when (eq (car (gnus-find-method-for-group group)) 'nndiary)
@@ -277,18 +277,18 @@
          'gnus-diary-update-group-parameters)
-;; Now that we have `gnus-subscribe-newsgroup-hooks', this is not needed
+;; Now that we have `gnus-subscribe-newsgroup-functions', this is not needed
 ;; anymore. Maybe I should remove this completely.

=== modified file 'lisp/net/tramp-gvfs.el'